% The Role of Money in Monetary Policy at the Lower Bound
% By Roberto M. Billi, Ulf Sderstrm and Carl E. Walsh
% This version: 3 September 2021

% MAKE FIGURES

% Initialize
clc, close all; clearvars
currentdir = cd;
%rho = -log(0.995)*100; %Percent
rho = 0;
np = 28;

% Gather results
cd dynare_results

load ini, ini_zn = endo_zn; ini_vn = endo_vn;
load inm, inm_zn = endo_zn; inm_vn = endo_vn;

load izi, izi_zn = endo_zn; izi_un = endo_un;
load izm, izm_zn = endo_zn; izm_un = endo_un; izm_vn = endo_vn;
load izp, izp_zn = endo_zn; izp_un = endo_un;

load inmetaL, inmetaL_zn = endo_zn; inmetaL_vn = endo_vn;
load izmetaL, izmetaL_zn = endo_zn; izmetaL_vn = endo_vn;
load izmetaH, izmetaH_zn = endo_zn; izmetaH_vn = endo_vn;

load izig, izig_zn = endo_zn;
load izmg, izmg_zn = endo_zn;
load izpg, izpg_zn = endo_zn;

cd beta0996
load izi, izi_beta0996 = endo_zn;
load izm, izm_beta0996 = endo_zn;
load izp, izp_beta0996 = endo_zn;
cd ../

cd mu045
load izi, izi_mu045 = endo_zn;
load izm, izm_mu045 = endo_zn;
load izp, izp_mu045 = endo_zn;
cd ../

cd ziid
load izi, izi_ziid = endo_zn;
load izm, izm_ziid = endo_zn;
load izp, izp_ziid = endo_zn;
cd ../

cd zn4
load izi, izi_zn4 = endo_zn;
load izm, izm_zn4 = endo_zn;
load izp, izp_zn4 = endo_zn;
cd ../

load wdni_eta,  wdni_eta = R;
load wdnm_eta,  wdnm_eta = R;
load wvni_eta,  wvni_eta = R;
load wvnm_eta,  wvnm_eta = R;
load wzni_eta,  wzni_eta = R;
load wznm_eta,  wznm_eta = R;

load wdzi_eta,  wdzi_eta = R;
load wdzm_eta,  wdzm_eta = R;
load wdzp_eta,  wdzp_eta = R;
load wvzi_eta,  wvzi_eta = R;
load wvzm_eta,  wvzm_eta = R;
load wvzp_eta,  wvzp_eta = R;
load wzzi_eta,  wzzi_eta = R;
load wzzm_eta,  wzzm_eta = R;
load wzzp_eta,  wzzp_eta = R;

load wdzi_psi,	wdzi_psi = R;
load wdzm_psi,	wdzm_psi = R;
load wdzp_psi,	wdzp_psi = R;
load wvzi_psi,	wvzi_psi = R;
load wvzm_psi,	wvzm_psi = R;
load wvzp_psi,	wvzp_psi = R;
load wzzi_psi,	wzzi_psi = R;
load wzzm_psi,	wzzm_psi = R;
load wzzp_psi,	wzzp_psi = R;

load wuni_psi,  wuni_psi = R;
load wunm_psi,  wunm_psi = R;
load wunp_psi,  wunp_psi = R;

cd psi019

load wdzi_psi,	wdzi_psi019 = R;
load wdzm_psi,	wdzm_psi019 = R;
load wdzp_psi,	wdzp_psi019 = R;
load wvzi_psi,	wvzi_psi019 = R;
load wvzm_psi,	wvzm_psi019 = R;
load wvzp_psi,	wvzp_psi019 = R;
load wzzi_psi,	wzzi_psi019 = R;
load wzzm_psi,	wzzm_psi019 = R;
load wzzp_psi,	wzzp_psi019 = R;

cd(currentdir)

% Make tables
disp('Table 2: Welfare loss under the baseline calibration')
disp('   L no ZLB; L with ZLB; ZLB frequency')
tab2_zi = round([wzni_eta(4,2),wzzi_eta(4,[2 9])],2);
tab2_zp = round([wzni_eta(4,2),wzzp_eta(4,[2 9])],2);
tab2_zm = round([wznm_eta(4,2),wzzm_eta(4,[2 9])],2);
tab2_vi = round([wvni_eta(4,2),wvzi_eta(4,[2 9])],2);
tab2_vp = round([wvni_eta(4,2),wvzp_eta(4,[2 9])],2);
tab2_vm = round([wvnm_eta(4,2),wvzm_eta(4,[2 9])],2);
tab2_di = round([wdni_eta(4,2),wdzi_eta(4,[2 9])],2);
tab2_dp = round([wdni_eta(4,2),wdzp_eta(4,[2 9])],2);
tab2_dm = round([wdnm_eta(4,2),wdzm_eta(4,[2 9])],2);
tab2_ui = round(wuni_psi(2),2);
tab2_up = round(wunp_psi(2),2);
tab2_um = round(wunm_psi(2),2);
disp('z shock only')
disp(['  IT: ',num2str(tab2_zi)])
disp([' PLT: ',num2str(tab2_zp)])
disp([' MGT: ',num2str(tab2_zm)])
disp('v shock only')
disp(['  IT: ',num2str(tab2_vi)])
disp([' PLT: ',num2str(tab2_vp)])
disp([' MGT: ',num2str(tab2_vm)])
disp('z and v shock')
disp(['  IT: ',num2str(tab2_di)])
disp([' PLT: ',num2str(tab2_dp)])
disp([' MGT: ',num2str(tab2_dm)])
disp('u shock only')
disp(['  IT: ',num2str(tab2_ui)])
disp([' PLT: ',num2str(tab2_up)])
disp([' MGT: ',num2str(tab2_um)])
disp(' ')

disp('Table 3: Effects of fiscal policy on welfare loss under the ZLB')
disp('   psi=0 -> L & ZLB frequency; psi=0.19 -> L & ZLB frequency')
tab3_zi = round([wzzi_psi(1,[2 9]),wzzi_psi019([2 9])],2);
tab3_zp = round([wzzp_psi(1,[2 9]),wzzp_psi019([2 9])],2);
tab3_zm = round([wzzm_psi(1,[2 9]),wzzm_psi019([2 9])],2);
tab3_vi = round([wvzi_psi(1,[2 9]),wvzi_psi019([2 9])],2);
tab3_vp = round([wvzp_psi(1,[2 9]),wvzp_psi019([2 9])],2);
tab3_vm = round([wvzm_psi(1,[2 9]),wvzm_psi019([2 9])],2);
tab3_di = round([wdzi_psi(1,[2 9]),wdzi_psi019([2 9])],2);
tab3_dp = round([wdzp_psi(1,[2 9]),wdzp_psi019([2 9])],2);
tab3_dm = round([wdzm_psi(1,[2 9]),wdzm_psi019([2 9])],2);
disp('z shock only')
disp(['  IT: ',num2str(tab3_zi)])
disp([' PLT: ',num2str(tab3_zp)])
disp([' MGT: ',num2str(tab3_zm)])
disp('v shock only')
disp(['  IT: ',num2str(tab3_vi)])
disp([' PLT: ',num2str(tab3_vp)])
disp([' MGT: ',num2str(tab3_vm)])
disp('z and v shock')
disp(['  IT: ',num2str(tab3_di)])
disp([' PLT: ',num2str(tab3_dp)])
disp([' MGT: ',num2str(tab3_dm)])

% Make figures
figure(2)

subplot(3,3,2)
plot(0:1:np,inm_zn(1,:),'-r',...
     0:1:np,ini_zn(1,:),'--b','LineWidth',1.5)
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)
legend('MGT','IT and PLT','location','best')

subplot(3,3,5)
plot(0:1:np,inm_zn(7,:),'-r',...
     0:1:np,ini_zn(7,:),'--b','LineWidth',1.5)
title('Price level (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,1)
plot(0:1:np,inm_zn(6,:)+rho,'-r',...
     0:1:np,ini_zn(6,:)+rho,'--b','LineWidth',1.5)
title('Real rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,9)
plot(0:1:np,inm_zn(11,:),'-r',...
     0:1:np,ini_zn(11,:),'--b','LineWidth',1.5)
title('Money growth (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,6)
plot(0:1:np,inm_zn(10,:),'-r',...
     0:1:np,ini_zn(10,:),'--b','LineWidth',1.5)
title('Money stock (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,4)
plot(0:1:np,inm_zn(4,:)+rho,'-r',...
     0:1:np,ini_zn(4,:)+rho,'--b','LineWidth',1.5)
title('Nominal rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,8)
plot(0:1:np,inm_zn(10,:)-inm_zn(7,:),'-r',...
     0:1:np,ini_zn(10,:)-ini_zn(7,:),'--b','LineWidth',1.5)
title('Real balance (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,3)
plot(0:1:np,inm_zn(2,:),'-r',...
     0:1:np,ini_zn(2,:),'--b','LineWidth',1.5)
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,7)
plot(0:1:np,inm_zn(14,:),'-r',...
     0:1:np,ini_zn(14,:),'--b','LineWidth',1.5)
title('shock z /\sigma_{z}','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

%%%%%%%%%
figure(3)

subplot(3,3,2)
plot(0:1:np,izp_zn(1,:),'-.k',...
     0:1:np,izm_zn(1,:),'-r',...
     0:1:np,izi_zn(1,:),'--b','LineWidth',1.5)
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)
legend('PLT','MGT','IT','location','best')

subplot(3,3,5)
plot(0:1:np,izp_zn(7,:),'-.k',...
     0:1:np,izm_zn(7,:),'-r',...
     0:1:np,izi_zn(7,:),'--b','LineWidth',1.5)
title('Price level (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,1)
plot(0:1:np,izp_zn(6,:)+rho,'-.k',...
     0:1:np,izm_zn(6,:)+rho,'-r',...
     0:1:np,izi_zn(6,:)+rho,'--b','LineWidth',1.5)
title('Real rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,9)
plot(0:1:np,izp_zn(11,:),'-.k',...
     0:1:np,izm_zn(11,:),'-r',...
     0:1:np,izi_zn(11,:),'--b','LineWidth',1.5)
title('Money growth (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,6)
plot(0:1:np,izp_zn(10,:),'-.k',...
     0:1:np,izm_zn(10,:),'-r',...
     0:1:np,izi_zn(10,:),'--b','LineWidth',1.5)
title('Money stock (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,4)
plot(0:1:np,izp_zn(4,:)+rho,'-.k',...
     0:1:np,izm_zn(4,:)+rho,'-r',...
     0:1:np,izi_zn(4,:)+rho,'--b','LineWidth',1.5)
title('Nominal rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,8)
plot(0:1:np,izp_zn(10,:)-izp_zn(7,:),'-.k',...
     0:1:np,izm_zn(10,:)-izm_zn(7,:),'-r',...
     0:1:np,izi_zn(10,:)-izi_zn(7,:),'--b','LineWidth',1.5)
title('Real balance (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,3)
plot(0:1:np,izp_zn(2,:),'-.k',...
     0:1:np,izm_zn(2,:),'-r',...
     0:1:np,izi_zn(2,:),'--b','LineWidth',1.5)
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,7)
plot(0:1:np,izp_zn(14,:),'-.k',...
     0:1:np,izm_zn(14,:),'-r',...
     0:1:np,izi_zn(14,:),'--b','LineWidth',1.5)
title('shock z /\sigma_{z}','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

%%%%%%%%%
figure(4)

subplot(3,3,2)
plot(0:1:np,inm_vn(1,:),'-.k',...
     0:1:np,izm_vn(1,:),'-r',...
     0:1:np,ini_vn(1,:),'--b','LineWidth',1.5)
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)
legend('MGT no ZLB','MGT with ZLB','IT and PLT','location','best')

subplot(3,3,5)
plot(0:1:np,inm_vn(7,:),'-.k',...
     0:1:np,izm_vn(7,:),'-r',...
     0:1:np,ini_vn(7,:),'--b','LineWidth',1.5)
title('Price level (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,1)
plot(0:1:np,inm_vn(6,:)+rho,'-.k',...
     0:1:np,izm_vn(6,:)+rho,'-r',...
     0:1:np,ini_vn(6,:)+rho,'--b','LineWidth',1.5)
title('Real rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,9)
plot(0:1:np,inm_vn(11,:),'-.k',...
     0:1:np,izm_vn(11,:),'-r',...
     0:1:np,ini_vn(11,:),'--b','LineWidth',1.5)
title('Money growth (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,6)
plot(0:1:np,inm_vn(10,:),'-.k',...
     0:1:np,izm_vn(10,:),'-r',...
     0:1:np,ini_vn(10,:),'--b','LineWidth',1.5)
title('Money stock (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,4)
plot(0:1:np,inm_vn(4,:)+rho,'-.k',...
     0:1:np,izm_vn(4,:)+rho,'-r',...
     0:1:np,ini_vn(4,:)+rho,'--b','LineWidth',1.5)
title('Nominal rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,8)
plot(0:1:np,inm_vn(10,:)-inm_vn(7,:),'-.k',...
     0:1:np,izm_vn(10,:)-izm_vn(7,:),'-r',...
     0:1:np,ini_vn(10,:)-ini_vn(7,:),'--b','LineWidth',1.5)
title('Real balance (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,3)
plot(0:1:np,inm_vn(2,:),'-.k',...
     0:1:np,izm_vn(2,:),'-r',...
     0:1:np,ini_vn(2,:),'--b','LineWidth',1.5)
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,7)
plot(0:1:np,inm_vn(13,:),'-.k',...
     0:1:np,izm_vn(13,:),'-r',...
     0:1:np,ini_vn(13,:),'--b','LineWidth',1.5)
title('shock v /\sigma_{v}','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

%%%%%%%%%
figure(5)

subplot(3,3,2)
plot(0:1:np,izmetaL_zn(1,:),'-.k',...
     0:1:np,izm_zn(1,:),'-r',...
     0:1:np,izmetaH_zn(1,:),'--b','LineWidth',1.5)
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)
legend('MGT \eta = 14','MGT \eta = \it{26}','MGT \eta = 38','location','best')

subplot(3,3,5)
plot(0:1:np,izmetaL_zn(7,:),'-.k',...
     0:1:np,izm_zn(7,:),'-r',...
     0:1:np,izmetaH_zn(7,:),'--b','LineWidth',1.5)
title('Price level (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,1)
plot(0:1:np,izmetaL_zn(6,:)+rho,'-.k',...
     0:1:np,izm_zn(6,:)+rho,'-r',...
     0:1:np,izmetaH_zn(6,:)+rho,'--b','LineWidth',1.5)
title('Real rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,9)
plot(0:1:np,izmetaL_zn(11,:),'-.k',...
     0:1:np,izm_zn(11,:),'-r',...
     0:1:np,izmetaH_zn(11,:),'--b','LineWidth',1.5)
title('Money growth (%)','Fontweight','normal')
xlabel('Quarters')
ylim([-1 1])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,6)
plot(0:1:np,izmetaL_zn(10,:),'-.k',...
     0:1:np,izm_zn(10,:),'-r',...
     0:1:np,izmetaH_zn(10,:),'--b','LineWidth',1.5)
title('Money stock (%)','Fontweight','normal')
xlabel('Quarters')
ylim([-1 1])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,4)
plot(0:1:np,izmetaL_zn(4,:)+rho,'-.k',...
     0:1:np,izm_zn(4,:)+rho,'-r',...
     0:1:np,izmetaH_zn(4,:)+rho,'--b','LineWidth',1.5)
title('Nominal rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,8)
plot(0:1:np,izmetaL_zn(10,:)-izmetaL_zn(7,:),'-.k',...
     0:1:np,izm_zn(10,:)-izm_zn(7,:),'-r',...
     0:1:np,izmetaH_zn(10,:)-izmetaH_zn(7,:),'--b','LineWidth',1.5)
title('Real balance (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,3)
plot(0:1:np,izmetaL_zn(2,:),'-.k',...
     0:1:np,izm_zn(2,:),'-r',...
     0:1:np,izmetaH_zn(2,:),'--b','LineWidth',1.5)
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,7)
plot(0:1:np,izmetaL_zn(14,:),'-.k',...
     0:1:np,izm_zn(14,:),'-r',...
     0:1:np,izmetaH_zn(14,:),'--b','LineWidth',1.5)
title('shock z /\sigma_{z}','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

%%%%%%%%%
figure(6)

subplot(3,3,2)
plot(0:1:np,izmetaL_vn(1,:),'-.k',...
     0:1:np,izm_vn(1,:),'-r',...
     0:1:np,izmetaH_vn(1,:),'--b','LineWidth',1.5)
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)
legend('MGT \eta = 14','MGT \eta = \it{26}','MGT \eta = 38','location','best')

subplot(3,3,5)
plot(0:1:np,izmetaL_vn(7,:),'-.k',...
     0:1:np,izm_vn(7,:),'-r',...
     0:1:np,izmetaH_vn(7,:),'--b','LineWidth',1.5)
title('Price level (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,1)
plot(0:1:np,izmetaL_vn(6,:)+rho,'-.k',...
     0:1:np,izm_vn(6,:)+rho,'-r',...
     0:1:np,izmetaH_vn(6,:)+rho,'--b','LineWidth',1.5)
title('Real rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,9)
plot(0:1:np,izmetaL_vn(11,:),'-.k',...
     0:1:np,izm_vn(11,:),'-r',...
     0:1:np,izmetaH_vn(11,:),'--b','LineWidth',1.5)
title('Money growth (%)','Fontweight','normal')
xlabel('Quarters')
ylim([-1 1])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,6)
plot(0:1:np,izmetaL_vn(10,:),'-.k',...
     0:1:np,izm_vn(10,:),'-r',...
     0:1:np,izmetaH_vn(10,:),'--b','LineWidth',1.5)
title('Money stock (%)','Fontweight','normal')
xlabel('Quarters')
ylim([-1 1])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,4)
plot(0:1:np,izmetaL_vn(4,:)+rho,'-.k',...
     0:1:np,izm_vn(4,:)+rho,'-r',...
     0:1:np,izmetaH_vn(4,:)+rho,'--b','LineWidth',1.5)
title('Nominal rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,8)
plot(0:1:np,izmetaL_vn(10,:)-izmetaL_vn(7,:),'-.k',...
     0:1:np,izm_vn(10,:)-izm_vn(7,:),'-r',...
     0:1:np,izmetaH_vn(10,:)-izmetaH_vn(7,:),'--b','LineWidth',1.5)
title('Real balance (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,3)
plot(0:1:np,izmetaL_vn(2,:),'-.k',...
     0:1:np,izm_vn(2,:),'-r',...
     0:1:np,izmetaH_vn(2,:),'--b','LineWidth',1.5)
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,7)
plot(0:1:np,izmetaL_vn(13,:),'-.k',...
     0:1:np,izm_vn(13,:),'-r',...
     0:1:np,izmetaH_vn(13,:),'--b','LineWidth',1.5)
title('shock v /\sigma_{v}','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

%%%%%%%%%
figure(7)

subplot(2,2,1)
plot(wznm_eta(:,1),wznm_eta(:,2),'-rd',...
     wzni_eta(:,1),wzni_eta(:,2),'-bo','LineWidth',1,'MarkerSize',5)
line(26*[1 1],[0 3],'color','k')
text(26.2*[1 1],0.5*[1 1],'\leftarrowBaseline')
title('Welfare loss if aggregate demand shock','Fontweight','normal')
ylabel('Percent')
xlabel('\eta')
ylim([0 2.1])
xlim(wzni_eta([1 end],1))
yticks(0:.5:2)
xticks(wzni_eta(:,1))
set(gca,'FontSize',9)
legend('MGT','IT and PLT','location','best')

subplot(2,2,2)
plot(wvnm_eta(:,1),wvnm_eta(:,2),'-rd',...
     wvni_eta(:,1),wvni_eta(:,2),'-bo','LineWidth',1,'MarkerSize',5)
line(26*[1 1],[0 3],'color','k')
title('Welfare loss if money demand shock','Fontweight','normal')
ylabel('Percent')
xlabel('\eta')
ylim([0 2.1])
xlim(wvni_eta([1 end],1))
yticks(0:.5:2)
xticks(wvni_eta(:,1))
set(gca,'FontSize',9)

subplot(2,2,3)
plot(wdnm_eta(:,1),wdnm_eta(:,2),'-rd',...
     wdni_eta(:,1),wdni_eta(:,2),'-bo','LineWidth',1,'MarkerSize',5)
line(26*[1 1],[0 3],'color','k')
title('Welfare loss if both types of shock','Fontweight','normal')
ylabel('Percent')
xlabel('\eta')
ylim([0 2.1])
xlim(wdni_eta([1 end],1))
yticks(0:.5:2)
xticks(wdni_eta(:,1))
set(gca,'FontSize',9)

%%%%%%%%%
figure(8)

subplot(3,2,1)
plot(wzzp_eta(:,1),wzzp_eta(:,2),'-kx',...
     wzzm_eta(:,1),wzzm_eta(:,2),'-rd',...
     wzzi_eta(:,1),wzzi_eta(:,2),'-bo','LineWidth',1,'MarkerSize',5)
line(26*[1 1],[0 5],'color','k')
text(26.2*[1 1],2.5*[1 1],'\leftarrowBaseline')
title('Aggregate demand shock:  Welfare loss','Fontweight','normal')
ylabel('Percent')
xlabel('\eta')
ylim([0 5])
xlim(wzzp_eta([1 end],1))
yticks(0:1:5)
xticks(wzzp_eta(:,1))
set(gca,'FontSize',9)
legend('PLT','MGT','IT','location','west')

subplot(3,2,2)
plot(wzzp_eta(:,1),wzzp_eta(:,9),'-kx',...
     wzzm_eta(:,1),wzzm_eta(:,9),'-rd',...
     wzzi_eta(:,1),wzzi_eta(:,9),'-bo','LineWidth',1,'MarkerSize',5)
line(26*[1 1],[0 30],'color','k')
title('ZLB frequency','Fontweight','normal')
ylabel('Percent')
xlabel('\eta')
ylim([0 27])
xlim(wzzp_eta([1 end],1))
yticks(0:5:25)
xticks(wzzp_eta(:,1))
set(gca,'FontSize',9)

subplot(3,2,3)
plot(wvzp_eta(:,1),wvzp_eta(:,2),'-kx',...
     wvzm_eta(:,1),wvzm_eta(:,2),'-rd',...
     wvzi_eta(:,1),wvzi_eta(:,2),'-bo','LineWidth',1,'MarkerSize',5)
line(26*[1 1],[0 5],'color','k')
title('Money demand shock:  Welfare loss','Fontweight','normal')
ylabel('Percent')
xlabel('\eta')
ylim([0 5])
xlim(wvzp_eta([1 end],1))
yticks(0:1:5)
xticks(wvzp_eta(:,1))
set(gca,'FontSize',9)

subplot(3,2,4)
plot(wvzp_eta(:,1),wvzp_eta(:,9),'-kx',...
     wvzm_eta(:,1),wvzm_eta(:,9),'-rd',...
     wvzi_eta(:,1),wvzi_eta(:,9),'-bo','LineWidth',1,'MarkerSize',5)
line(26*[1 1],[0 30],'color','k')
title('ZLB frequency','Fontweight','normal')
ylabel('Percent')
xlabel('\eta')
ylim([0 27])
xlim(wvzp_eta([1 end],1))
yticks(0:5:25)
xticks(wvzp_eta(:,1))
set(gca,'FontSize',9)

subplot(3,2,5)
plot(wdzp_eta(:,1),wdzp_eta(:,2),'-kx',...
     wdzm_eta(:,1),wdzm_eta(:,2),'-rd',...
     wdzi_eta(:,1),wdzi_eta(:,2),'-bo','LineWidth',1,'MarkerSize',5)
line(26*[1 1],[0 5],'color','k')
title('Both types of shock:  Welfare loss','Fontweight','normal')
ylabel('Percent')
xlabel('\eta')
ylim([0 5])
xlim(wdzp_eta([1 end],1))
yticks(0:1:5)
xticks(wdzp_eta(:,1))
set(gca,'FontSize',9)

subplot(3,2,6)
plot(wdzp_eta(:,1),wdzp_eta(:,9),'-kx',...
     wdzm_eta(:,1),wdzm_eta(:,9),'-rd',...
     wdzi_eta(:,1),wdzi_eta(:,9),'-bo','LineWidth',1,'MarkerSize',5)
line(26*[1 1],[0 30],'color','k')
title('ZLB frequency','Fontweight','normal')
ylabel('Percent')
xlabel('\eta')
ylim([0 27])
xlim(wdzp_eta([1 end],1))
yticks(0:5:25)
xticks(wdzp_eta(:,1))
set(gca,'FontSize',9)

%%%%%%%%%
figure(9)

subplot(5,2,1)
plot(0:1:np,izp_zn(3,:),'-.k',...
     0:1:np,izm_zn(3,:),'-r',...
     0:1:np,izi_zn(3,:),'--b','LineWidth',1.5)
line(9*[1 1],[-1 1],'color','k','LineStyle','--')
title({'No fiscal response \psi = 0:','Gov purchases (%)'},'Fontweight','normal')
xlabel('Quarters')
ylim([-1 1])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(5,2,2)
plot(0:1:np,izpg_zn(3,:),'-.k',...
     0:1:np,izmg_zn(3,:),'-r',...
     0:1:np,izig_zn(3,:),'--b','LineWidth',1.5)
text(9.2*[1 1],0.5*[1 1],'\leftarrowIT liftoff')
line(9*[1 1],20*[-1 1],'color','k','LineStyle','--')
title({'ARRA fiscal responsiveness \psi = 0.19:','Gov purchases (%)'},'Fontweight','normal')
xlabel('Quarters')
ylim([0 max([izpg_zn(3,:) izmg_zn(3,:) izig_zn(3,:)])])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)
legend('PLT','MGT','IT','location','best')

subplot(5,2,3)
plot(0:1:np,izp_zn(2,:),'-.k',...
     0:1:np,izm_zn(2,:),'-r',...
     0:1:np,izi_zn(2,:),'--b','LineWidth',1.5)
line(9*[1 1],20*[-1 1],'color','k','LineStyle','--')
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
ylim([min([izp_zn(2,:) izm_zn(2,:) izi_zn(2,:)]) max([izp_zn(2,:) izm_zn(2,:) izi_zn(2,:)])])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(5,2,4)
plot(0:1:np,izpg_zn(2,:),'-.k',...
     0:1:np,izmg_zn(2,:),'-r',...
     0:1:np,izig_zn(2,:),'--b','LineWidth',1.5)
line(9*[1 1],20*[-1 1],'color','k','LineStyle','--')
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
ylim([min([izpg_zn(2,:) izmg_zn(2,:) izig_zn(2,:)]) max([izpg_zn(2,:) izmg_zn(2,:) izig_zn(2,:)])])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(5,2,5)
plot(0:1:np,izp_zn(1,:),'-.k',...
     0:1:np,izm_zn(1,:),'-r',...
     0:1:np,izi_zn(1,:),'--b','LineWidth',1.5)
line(9*[1 1],20*[-1 1],'color','k','LineStyle','--')
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
ylim([min([izp_zn(1,:) izm_zn(1,:) izi_zn(1,:)]) max([izp_zn(1,:) izm_zn(1,:) izi_zn(1,:)])])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(5,2,6)
plot(0:1:np,izpg_zn(1,:),'-.k',...
     0:1:np,izmg_zn(1,:),'-r',...
     0:1:np,izig_zn(1,:),'--b','LineWidth',1.5)
line(9*[1 1],20*[-1 1],'color','k','LineStyle','--')
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
ylim([min([izpg_zn(1,:) izmg_zn(1,:) izig_zn(1,:)]) max([izpg_zn(1,:) izmg_zn(1,:) izig_zn(1,:)])])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(5,2,7)
plot(0:1:np,izp_zn(4,:)+rho,'-.k',...
     0:1:np,izm_zn(4,:)+rho,'-r',...
     0:1:np,izi_zn(4,:)+rho,'--b','LineWidth',1.5)
line(9*[1 1],[-1 1],'color','k','LineStyle','--')
title('Nominal interest rate (%)','Fontweight','normal')
xlabel('Quarters')
ylim([-0.6 0])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(5,2,8)
plot(0:1:np,izpg_zn(4,:)+rho,'-.k',...
     0:1:np,izmg_zn(4,:)+rho,'-r',...
     0:1:np,izig_zn(4,:)+rho,'--b','LineWidth',1.5)
line(9*[1 1],[-1 1],'color','k','LineStyle','--')
title('Nominal interest rate (%)','Fontweight','normal')
xlabel('Quarters')
ylim([-0.6 0])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(5,2,9)
plot(0:1:np,izp_zn(5,:)+rho,'-.k',...
     0:1:np,izm_zn(5,:)+rho,'-r',...
     0:1:np,izi_zn(5,:)+rho,'--b','LineWidth',1.5)
line(9*[1 1],2*[-1 1],'color','k','LineStyle','--')
title('Natural interest rate (%)','Fontweight','normal')
xlabel('Quarters')
ylim([-1.5 0])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(5,2,10)
plot(0:1:np,izpg_zn(5,:)+rho,'-.k',...
     0:1:np,izmg_zn(5,:)+rho,'-r',...
     0:1:np,izig_zn(5,:)+rho,'--b','LineWidth',1.5)
line(9*[1 1],[-1 1],'color','k','LineStyle','--')
title('Natural interest rate (%)','Fontweight','normal')
xlabel('Quarters')
ylim([-1.1 0])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

%%%%%%%%%
figure(10)

subplot(3,2,1)
plot(wzzp_psi(:,1),wzzp_psi(:,2),'-kx',...
     wzzm_psi(:,1),wzzm_psi(:,2),'-rd',...
     wzzi_psi(:,1),wzzi_psi(:,2),'-bo','LineWidth',1,'MarkerSize',5)
line(.19*[1 1],[0 30],'color','k','LineStyle','--')
line(.27*[1 1],[0 30],'color','k','LineStyle','-.')
line(.45*[1 1],[0 30],'color','k','LineStyle',':')
text(.05*[1 1],4.5*[1 1],'ARRA\rightarrow')
text(.27*[1 1],3.8*[1 1],'\leftarrowCARES')
text(.33*[1 1],2.6*[1 1],'ARP\rightarrow')
title('Aggregate demand shock:  Welfare loss','Fontweight','normal')
ylabel('Percent')
xlabel('\psi')
ylim([0 5])
xlim([0 .7])
yticks(0:1:5)
xticks(0:.1:1)
xticklabels({'0','.1','.2','.3','.4','.5','.6','.7','.8','.9','1'})
set(gca,'FontSize',9)
legend('PLT','MGT','IT','location','best')

subplot(3,2,2)
plot(wzzp_psi(:,1),wzzp_psi(:,9),'-kx',...
     wzzm_psi(:,1),wzzm_psi(:,9),'-rd',...
     wzzi_psi(:,1),wzzi_psi(:,9),'-bo','LineWidth',1,'MarkerSize',5)
line(.19*[1 1],[0 30],'color','k','LineStyle','--')
line(.27*[1 1],[0 30],'color','k','LineStyle','-.')
line(.45*[1 1],[0 30],'color','k','LineStyle',':')
title('ZLB frequency','Fontweight','normal')
ylabel('Percent')
xlabel('\psi')
ylim([0 27])
xlim([0 .7])
yticks(0:5:25)
xticks(0:.1:1)
xticklabels({'0','.1','.2','.3','.4','.5','.6','.7','.8','.9','1'})
set(gca,'FontSize',9)

subplot(3,2,3)
plot(wvzp_psi(:,1),wvzp_psi(:,2),'-kx',...
     wvzm_psi(:,1),wvzm_psi(:,2),'-rd',...
     wvzi_psi(:,1),wvzi_psi(:,2),'-bo','LineWidth',1,'MarkerSize',5)
line(.19*[1 1],[0 30],'color','k','LineStyle','--')
line(.27*[1 1],[0 30],'color','k','LineStyle','-.')
line(.45*[1 1],[0 30],'color','k','LineStyle',':')
title('Money demand shock:  Welfare loss','Fontweight','normal')
ylabel('Percent')
xlabel('\psi')
ylim([0 1])
xlim([0 .7])
xticks(0:.1:1)
xticklabels({'0','.1','.2','.3','.4','.5','.6','.7','.8','.9','1'})
set(gca,'FontSize',9)

subplot(3,2,4)
plot(wvzp_psi(:,1),wvzp_psi(:,9),'-kx',...
     wvzm_psi(:,1),wvzm_psi(:,9),'-rd',...
     wvzi_psi(:,1),wvzi_psi(:,9),'-bo','LineWidth',1,'MarkerSize',5)
line(.19*[1 1],[0 30],'color','k','LineStyle','--')
line(.27*[1 1],[0 30],'color','k','LineStyle','-.')
line(.45*[1 1],[0 30],'color','k','LineStyle',':')
title('ZLB frequency','Fontweight','normal')
ylabel('Percent')
xlabel('\psi')
ylim([0 27])
xlim([0 .7])
yticks(0:5:25)
xticklabels({'0','.1','.2','.3','.4','.5','.6','.7','.8','.9','1'})
set(gca,'FontSize',9)

subplot(3,2,5)
plot(wdzp_psi(:,1),wdzp_psi(:,2),'-kx',...
     wdzm_psi(:,1),wdzm_psi(:,2),'-rd',...
     wdzi_psi(:,1),wdzi_psi(:,2),'-bo','LineWidth',1,'MarkerSize',5)
line(.19*[1 1],[0 30],'color','k','LineStyle','--')
line(.27*[1 1],[0 30],'color','k','LineStyle','-.')
line(.45*[1 1],[0 30],'color','k','LineStyle',':')
title('Both types of shock:  Welfare loss','Fontweight','normal')
ylabel('Percent')
xlabel('\psi')
ylim([0 5])
xlim([0 .7])
yticks(0:1:5)
xticks(0:.1:1)
xticklabels({'0','.1','.2','.3','.4','.5','.6','.7','.8','.9','1'})
set(gca,'FontSize',9)

subplot(3,2,6)
plot(wdzp_psi(:,1),wdzp_psi(:,9),'-kx',...
     wdzm_psi(:,1),wdzm_psi(:,9),'-rd',...
     wdzi_psi(:,1),wdzi_psi(:,9),'-bo','LineWidth',1,'MarkerSize',5)
line(.19*[1 1],[0 30],'color','k','LineStyle','--')
line(.27*[1 1],[0 30],'color','k','LineStyle','-.')
line(.45*[1 1],[0 30],'color','k','LineStyle',':')
title('ZLB frequency','Fontweight','normal')
ylabel('Percent')
xlabel('\psi')
ylim([0 27])
xlim([0 .7])
yticks(0:5:25)
xticks(0:.1:1)
xticklabels({'0','.1','.2','.3','.4','.5','.6','.7','.8','.9','1'})
set(gca,'FontSize',9)

%%%%%%%%%
figure(11)

subplot(3,3,2)
plot(0:1:np,izp_mu045(1,:),'-.k',...
     0:1:np,izm_mu045(1,:),'-r',...
     0:1:np,izi_mu045(1,:),'--b','LineWidth',1.5)
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)
legend('PLT','MGT','IT','location','best')

subplot(3,3,5)
plot(0:1:np,izp_mu045(7,:),'-.k',...
     0:1:np,izm_mu045(7,:),'-r',...
     0:1:np,izi_mu045(7,:),'--b','LineWidth',1.5)
title('Price level (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,1)
plot(0:1:np,izp_mu045(6,:)+rho,'-.k',...
     0:1:np,izm_mu045(6,:)+rho,'-r',...
     0:1:np,izi_mu045(6,:)+rho,'--b','LineWidth',1.5)
title('Real rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,9)
plot(0:1:np,izp_mu045(11,:),'-.k',...
     0:1:np,izm_mu045(11,:),'-r',...
     0:1:np,izi_mu045(11,:),'--b','LineWidth',1.5)
title('Money growth (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,6)
plot(0:1:np,izp_mu045(10,:),'-.k',...
     0:1:np,izm_mu045(10,:),'-r',...
     0:1:np,izi_mu045(10,:),'--b','LineWidth',1.5)
title('Money stock (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,4)
plot(0:1:np,izp_mu045(4,:)+rho,'-.k',...
     0:1:np,izm_mu045(4,:)+rho,'-r',...
     0:1:np,izi_mu045(4,:)+rho,'--b','LineWidth',1.5)
title('Nominal rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,8)
plot(0:1:np,izp_mu045(10,:)-izp_mu045(7,:),'-.k',...
     0:1:np,izm_mu045(10,:)-izm_mu045(7,:),'-r',...
     0:1:np,izi_mu045(10,:)-izi_mu045(7,:),'--b','LineWidth',1.5)
title('Real balance (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,3)
plot(0:1:np,izp_mu045(2,:),'-.k',...
     0:1:np,izm_mu045(2,:),'-r',...
     0:1:np,izi_mu045(2,:),'--b','LineWidth',1.5)
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,7)
plot(0:1:np,izp_mu045(14,:),'-.k',...
     0:1:np,izm_mu045(14,:),'-r',...
     0:1:np,izi_mu045(14,:),'--b','LineWidth',1.5)
title('shock z /\sigma_{z}','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

%%%%%%%%%
figure(12)

subplot(3,3,2)
plot(0:1:np,izp_un(1,:),'-.k',...
     0:1:np,izm_un(1,:),'-r',...
     0:1:np,izi_un(1,:),'--b','LineWidth',1.5)
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)
legend('PLT','MGT','IT','location','best')

subplot(3,3,5)
plot(0:1:np,izp_un(7,:),'-.k',...
     0:1:np,izm_un(7,:),'-r',...
     0:1:np,izi_un(7,:),'--b','LineWidth',1.5)
title('Price level (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,1)
plot(0:1:np,izp_un(6,:)+rho,'-.k',...
     0:1:np,izm_un(6,:)+rho,'-r',...
     0:1:np,izi_un(6,:)+rho,'--b','LineWidth',1.5)
title('Real rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,9)
plot(0:1:np,izp_un(11,:),'-.k',...
     0:1:np,izm_un(11,:),'-r',...
     0:1:np,izi_un(11,:),'--b','LineWidth',1.5)
title('Money growth (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,6)
plot(0:1:np,izp_un(10,:),'-.k',...
     0:1:np,izm_un(10,:),'-r',...
     0:1:np,izi_un(10,:),'--b','LineWidth',1.5)
title('Money stock (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,4)
plot(0:1:np,izp_un(4,:)+rho,'-.k',...
     0:1:np,izm_un(4,:)+rho,'-r',...
     0:1:np,izi_un(4,:)+rho,'--b','LineWidth',1.5)
title('Nominal rate (%)','Fontweight','normal')
xlabel('Quarters')
ylim([-0.6 0])
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,8)
plot(0:1:np,izp_un(10,:)-izp_un(7,:),'-.k',...
     0:1:np,izm_un(10,:)-izm_un(7,:),'-r',...
     0:1:np,izi_un(10,:)-izi_un(7,:),'--b','LineWidth',1.5)
title('Real balance (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,3)
plot(0:1:np,izp_un(2,:),'-.k',...
     0:1:np,izm_un(2,:),'-r',...
     0:1:np,izi_un(2,:),'--b','LineWidth',1.5)
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,7)
plot(0:1:np,izp_un(12,:),'-.k',...
     0:1:np,izm_un(12,:),'-r',...
     0:1:np,izi_un(12,:),'--b','LineWidth',1.5)
title('shock u /\sigma_{u}','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

%%%%%%%%%
figure(13)

subplot(3,2,1)
plot(wzzp_psi(:,1),wzzp_psi(:,3),'-kx',...
     wzzm_psi(:,1),wzzm_psi(:,3),'-rd',...
     wzzi_psi(:,1),wzzi_psi(:,3),'-bo','LineWidth',1,'MarkerSize',5)
line(.19*[1 1],[0 30],'color','k','LineStyle','--')
line(.27*[1 1],[0 30],'color','k','LineStyle','-.')
line(.45*[1 1],[0 30],'color','k','LineStyle',':')
text(.05*[1 1],4.5*[1 1],'ARRA\rightarrow')
text(.27*[1 1],3.8*[1 1],'\leftarrowCARES')
text(.33*[1 1],2.6*[1 1],'ARP\rightarrow')
title('Aggregate demand shock:  Welfare loss','Fontweight','normal')
ylabel('Percent')
xlabel('\psi')
ylim([0 5])
xlim([0 .7])
yticks(0:1:5)
xticks(0:.1:1)
xticklabels({'0','.1','.2','.3','.4','.5','.6','.7','.8','.9','1'})
set(gca,'FontSize',9)
legend('PLT','MGT','IT','location','best')

subplot(3,2,2)
plot(wzzp_psi(:,1),wzzp_psi(:,7),'-kx',...
     wzzm_psi(:,1),wzzm_psi(:,7),'-rd',...
     wzzi_psi(:,1),wzzi_psi(:,7),'-bo','LineWidth',1,'MarkerSize',5)
line(.19*[1 1],[0 30],'color','k','LineStyle','--')
line(.27*[1 1],[0 30],'color','k','LineStyle','-.')
line(.45*[1 1],[0 30],'color','k','LineStyle',':')
title('Loss from money holdings','Fontweight','normal')
ylabel('Percent')
xlabel('\psi')
ylim([0 0.3])
xlim([0 .7])
xticks(0:.1:1)
xticklabels({'0','.1','.2','.3','.4','.5','.6','.7','.8','.9','1'})
set(gca,'FontSize',9)

subplot(3,2,3)
plot(wvzp_psi(:,1),wvzp_psi(:,3),'-kx',...
     wvzm_psi(:,1),wvzm_psi(:,3),'-rd',...
     wvzi_psi(:,1),wvzi_psi(:,3),'-bo','LineWidth',1,'MarkerSize',5)
line(.19*[1 1],[0 30],'color','k','LineStyle','--')
line(.27*[1 1],[0 30],'color','k','LineStyle','-.')
line(.45*[1 1],[0 30],'color','k','LineStyle',':')
title('Money demand shock:  Welfare loss','Fontweight','normal')
ylabel('Percent')
xlabel('\psi')
ylim([0 1])
xlim([0 .7])
xticks(0:.1:1)
xticklabels({'0','.1','.2','.3','.4','.5','.6','.7','.8','.9','1'})
set(gca,'FontSize',9)

subplot(3,2,4)
plot(wzzp_psi(:,1),wvzp_psi(:,7),'-kx',...
     wzzm_psi(:,1),wvzm_psi(:,7),'-rd',...
     wzzi_psi(:,1),wvzi_psi(:,7),'-bo','LineWidth',1,'MarkerSize',5)
line(.19*[1 1],[0 30],'color','k','LineStyle','--')
line(.27*[1 1],[0 30],'color','k','LineStyle','-.')
line(.45*[1 1],[0 30],'color','k','LineStyle',':')
title('Loss from money holdings','Fontweight','normal')
ylabel('Percent')
xlabel('\psi')
ylim([0 0.3])
xlim([0 .7])
xticks(0:.1:1)
xticklabels({'0','.1','.2','.3','.4','.5','.6','.7','.8','.9','1'})
set(gca,'FontSize',9)

subplot(3,2,5)
plot(wdzp_psi(:,1),wdzp_psi(:,3),'-kx',...
     wdzm_psi(:,1),wdzm_psi(:,3),'-rd',...
     wdzi_psi(:,1),wdzi_psi(:,3),'-bo','LineWidth',1,'MarkerSize',5)
line(.19*[1 1],[0 30],'color','k','LineStyle','--')
line(.27*[1 1],[0 30],'color','k','LineStyle','-.')
line(.45*[1 1],[0 30],'color','k','LineStyle',':')
title('Both types of shock:  Welfare loss','Fontweight','normal')
ylabel('Percent')
xlabel('\psi')
ylim([0 5])
xlim([0 .7])
yticks(0:1:5)
xticks(0:.1:1)
xticklabels({'0','.1','.2','.3','.4','.5','.6','.7','.8','.9','1'})
set(gca,'FontSize',9)

subplot(3,2,6)
plot(wzzp_psi(:,1),wdzp_psi(:,7),'-kx',...
     wzzm_psi(:,1),wdzm_psi(:,7),'-rd',...
     wzzi_psi(:,1),wdzi_psi(:,7),'-bo','LineWidth',1,'MarkerSize',5)
line(.19*[1 1],[0 30],'color','k','LineStyle','--')
line(.27*[1 1],[0 30],'color','k','LineStyle','-.')
line(.45*[1 1],[0 30],'color','k','LineStyle',':')
title('Loss from money holdings','Fontweight','normal')
ylabel('Percent')
xlabel('\psi')
ylim([0 0.3])
xlim([0 .7])
xticks(0:.1:1)
xticklabels({'0','.1','.2','.3','.4','.5','.6','.7','.8','.9','1'})
set(gca,'FontSize',9)

%%%%%%%%%
figure(14), np2=8;

subplot(3,3,2)
plot(0:1:np,izm_ziid(1,:),'-r',...
     0:1:np,izi_ziid(1,:),'--b','LineWidth',1.5)
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np2])
xticks(0:1:np)
set(gca,'FontSize',9)
legend('MGT','IT','location','best')

subplot(3,3,5)
plot(0:1:np,izm_ziid(7,:),'-r',...
     0:1:np,izi_ziid(7,:),'--b','LineWidth',1.5)
title('Price level (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np2])
xticks(0:1:np)
set(gca,'FontSize',9)

subplot(3,3,1)
plot(0:1:np,izm_ziid(6,:)+rho,'-r',...
     0:1:np,izi_ziid(6,:)+rho,'--b','LineWidth',1.5)
title('Real rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np2])
xticks(0:1:np)
set(gca,'FontSize',9)

subplot(3,3,9)
plot(0:1:np,izm_ziid(11,:),'-r',...
     0:1:np,izi_ziid(11,:),'--b','LineWidth',1.5)
title('Money growth (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np2])
xticks(0:1:np)
set(gca,'FontSize',9)

subplot(3,3,6)
plot(0:1:np,izm_ziid(10,:),'-r',...
     0:1:np,izi_ziid(10,:),'--b','LineWidth',1.5)
title('Money stock (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np2])
xticks(0:1:np)
set(gca,'FontSize',9)

subplot(3,3,4)
plot(0:1:np,izm_ziid(4,:)+rho,'-r',...
     0:1:np,izi_ziid(4,:)+rho,'--b','LineWidth',1.5)
title('Nominal rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np2])
xticks(0:1:np)
set(gca,'FontSize',9)

subplot(3,3,8)
plot(0:1:np,izm_ziid(10,:)-izm_ziid(7,:),'-r',...
     0:1:np,izi_ziid(10,:)-izi_ziid(7,:),'--b','LineWidth',1.5)
title('Real balance (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np2])
xticks(0:1:np)
set(gca,'FontSize',9)

subplot(3,3,3)
plot(0:1:np,izm_ziid(2,:),'-r',...
     0:1:np,izi_ziid(2,:),'--b','LineWidth',1.5)
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np2])
xticks(0:1:np)
set(gca,'FontSize',9)

subplot(3,3,7)
plot(0:1:np,izm_ziid(14,:),'-r',...
     0:1:np,izi_ziid(14,:),'--b','LineWidth',1.5)
title('shock z /\sigma_{z}','Fontweight','normal')
xlabel('Quarters')
xlim([0 np2])
xticks(0:1:np)
set(gca,'FontSize',9)

%%%%%%%%%
figure(15)

subplot(3,3,2)
plot(0:1:np,izm_zn4(1,:),'-r',...
     0:1:np,izi_zn4(1,:),'--b','LineWidth',1.5)
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)
legend('MGT','IT','location','best')

subplot(3,3,5)
plot(0:1:np,izm_zn4(7,:),'-r',...
     0:1:np,izi_zn4(7,:),'--b','LineWidth',1.5)
title('Price level (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,1)
plot(0:1:np,izm_zn4(6,:)+rho,'-r',...
     0:1:np,izi_zn4(6,:)+rho,'--b','LineWidth',1.5)
title('Real rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,9)
plot(0:1:np,izm_zn4(11,:),'-r',...
     0:1:np,izi_zn4(11,:),'--b','LineWidth',1.5)
title('Money growth (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,6)
plot(0:1:np,izm_zn4(10,:),'-r',...
     0:1:np,izi_zn4(10,:),'--b','LineWidth',1.5)
title('Money stock (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,4)
plot(0:1:np,izm_zn4(4,:)+rho,'-r',...
     0:1:np,izi_zn4(4,:)+rho,'--b','LineWidth',1.5)
title('Nominal rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,8)
plot(0:1:np,izm_zn4(10,:)-izm_zn4(7,:),'-r',...
     0:1:np,izi_zn4(10,:)-izi_zn4(7,:),'--b','LineWidth',1.5)
title('Real balance (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,3)
plot(0:1:np,izm_zn4(2,:),'-r',...
     0:1:np,izi_zn4(2,:),'--b','LineWidth',1.5)
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,7)
plot(0:1:np,izm_zn4(14,:),'-r',...
     0:1:np,izi_zn4(14,:),'--b','LineWidth',1.5)
title('shock z /\sigma_{z}','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

%%%%%%%%%
figure(16)

subplot(3,3,2)
plot(0:1:np,izp_beta0996(1,:),'-.k',...
     0:1:np,izm_beta0996(1,:),'-r',...
     0:1:np,izi_beta0996(1,:),'--b','LineWidth',1.5)
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)
legend('PLT','MGT','IT','location','best')

subplot(3,3,5)
plot(0:1:np,izp_beta0996(7,:),'-.k',...
     0:1:np,izm_beta0996(7,:),'-r',...
     0:1:np,izi_beta0996(7,:),'--b','LineWidth',1.5)
title('Price level (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,1)
plot(0:1:np,izp_beta0996(6,:)+rho,'-.k',...
     0:1:np,izm_beta0996(6,:)+rho,'-r',...
     0:1:np,izi_beta0996(6,:)+rho,'--b','LineWidth',1.5)
title('Real rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,9)
plot(0:1:np,izp_beta0996(11,:),'-.k',...
     0:1:np,izm_beta0996(11,:),'-r',...
     0:1:np,izi_beta0996(11,:),'--b','LineWidth',1.5)
title('Money growth (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,6)
plot(0:1:np,izp_beta0996(10,:),'-.k',...
     0:1:np,izm_beta0996(10,:),'-r',...
     0:1:np,izi_beta0996(10,:),'--b','LineWidth',1.5)
title('Money stock (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,4)
plot(0:1:np,izp_beta0996(4,:)+rho,'-.k',...
     0:1:np,izm_beta0996(4,:)+rho,'-r',...
     0:1:np,izi_beta0996(4,:)+rho,'--b','LineWidth',1.5)
title('Nominal rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,8)
plot(0:1:np,izp_beta0996(10,:)-izp_beta0996(7,:),'-.k',...
     0:1:np,izm_beta0996(10,:)-izm_beta0996(7,:),'-r',...
     0:1:np,izi_beta0996(10,:)-izi_beta0996(7,:),'--b','LineWidth',1.5)
title('Real balance (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,3)
plot(0:1:np,izp_beta0996(2,:),'-.k',...
     0:1:np,izm_beta0996(2,:),'-r',...
     0:1:np,izi_beta0996(2,:),'--b','LineWidth',1.5)
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,7)
plot(0:1:np,izp_beta0996(14,:),'-.k',...
     0:1:np,izm_beta0996(14,:),'-r',...
     0:1:np,izi_beta0996(14,:),'--b','LineWidth',1.5)
title('shock z /\sigma_{z}','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

%%%%%%%%%
figure(17)

subplot(3,3,2)
plot(0:1:np,inmetaL_vn(1,:),'-.k',...
     0:1:np,izmetaL_vn(1,:),'-r',...
     0:1:np,ini_vn(1,:),'--b','LineWidth',1.5)
title('Inflation (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)
legend('MGT no ZLB','MGT with ZLB','IT and PLT','location','best')

subplot(3,3,5)
plot(0:1:np,inmetaL_vn(7,:),'-.k',...
     0:1:np,izmetaL_vn(7,:),'-r',...
     0:1:np,ini_vn(7,:),'--b','LineWidth',1.5)
title('Price level (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,1)
plot(0:1:np,inmetaL_vn(6,:)+rho,'-.k',...
     0:1:np,izmetaL_vn(6,:)+rho,'-r',...
     0:1:np,ini_vn(6,:)+rho,'--b','LineWidth',1.5)
title('Real rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,9)
plot(0:1:np,inmetaL_vn(11,:),'-.k',...
     0:1:np,izmetaL_vn(11,:),'-r',...
     0:1:np,ini_vn(11,:),'--b','LineWidth',1.5)
title('Money growth (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,6)
plot(0:1:np,inmetaL_vn(10,:),'-.k',...
     0:1:np,izmetaL_vn(10,:),'-r',...
     0:1:np,ini_vn(10,:),'--b','LineWidth',1.5)
title('Money stock (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,4)
plot(0:1:np,inmetaL_vn(4,:)+rho,'-.k',...
     0:1:np,izmetaL_vn(4,:)+rho,'-r',...
     0:1:np,ini_vn(4,:)+rho,'--b','LineWidth',1.5)
title('Nominal rate (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,8)
plot(0:1:np,inmetaL_vn(10,:)-inmetaL_vn(7,:),'-.k',...
     0:1:np,izmetaL_vn(10,:)-izmetaL_vn(7,:),'-r',...
     0:1:np,ini_vn(10,:)-ini_vn(7,:),'--b','LineWidth',1.5)
title('Real balance (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,3)
plot(0:1:np,inmetaL_vn(2,:),'-.k',...
     0:1:np,izmetaL_vn(2,:),'-r',...
     0:1:np,ini_vn(2,:),'--b','LineWidth',1.5)
title('Output gap (%)','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

subplot(3,3,7)
plot(0:1:np,inmetaL_vn(13,:),'-.k',...
     0:1:np,izmetaL_vn(13,:),'-r',...
     0:1:np,ini_vn(13,:),'--b','LineWidth',1.5)
title('shock v /\sigma_{v}','Fontweight','normal')
xlabel('Quarters')
xlim([0 np])
xticks(0:4:np)
set(gca,'FontSize',9)

% Save figures
print( 2,'fig02','-dpsc','-bestfit')
print( 3,'fig03','-dpsc','-bestfit')
print( 4,'fig04','-dpsc','-bestfit')
print( 5,'fig05','-dpsc','-bestfit')
print( 6,'fig06','-dpsc','-bestfit')
print( 7,'fig07','-dpsc','-bestfit')
print( 8,'fig08','-dpsc','-bestfit')
print( 9,'fig09','-dpsc','-fillpage')
print(10,'fig10','-dpsc','-bestfit')
print(11,'figA1','-dpsc','-bestfit')
print(12,'figA2','-dpsc','-bestfit')
print(13,'figA3','-dpsc','-bestfit')
print(14,'figR1','-dpsc','-bestfit')
print(15,'figR2','-dpsc','-bestfit')
print(16,'figR3','-dpsc','-bestfit')
print(17,'figR4','-dpsc','-bestfit')
close all