% The Role of Money in Monetary Policy at the Lower Bound
% By Roberto M. Billi, Ulf Sderstrm and Carl E. Walsh
% This version: 30 August 2021

@#define WELFARE = 0
@#define WELFARE_u_shock = 0
@#define WELFARE_v_shock = 0
@#define WELFARE_z_shock = 0
@#define WELFARE_demand_shocks = 0
@#define WELFARE_LOOP_eta = 0
@#define WELFARE_LOOP_psi = 0
@#define IMPULSE = 1
@#define IMPULSE_etaL = 0
@#define IMPULSE_etaH = 0
@#define IMPULSE_sigmaH = 0
@#define IMPULSE_g = 0
@#define ZLB = 1
@#define MP_i = 1
@#define MP_m = 0
@#define MP_p = 0

%   1  2  3 4 5  6 7 8 9 10 11 12 13 14
VAR pi yh g i rn r p y c m  dm u  v  z;

VAREXO epsu epsv epsz;

PARAMETERS beta sigma delta varphi eps alpha theta eta psi
           rhou rhov rhoz sigu sigv sigz mu rho lambda kappa Gamma gamma;

% Loop over values of "eta"
eta_vec = 14:4:38;
@#if WELFARE_LOOP_eta
    for je = 1:length(eta_vec)
@#else
	for je = 4 % use the "middle" value for baseline
@#endif
eta = eta_vec(je);

@#if IMPULSE_etaL
	eta = 14;
@#endif
@#if IMPULSE_etaH
	eta = 38;
@#endif

% Loop over values of "psi"
% psi_vec = 0;
% psi_vec = 0.19;
psi_vec = 0:.1:1;
@#if WELFARE_LOOP_psi
    for jp = 1:length(psi_vec)
@#else
	for jp = 1 % use the "lowest" value for baseline
@#endif
psi = psi_vec(jp);

@#if IMPULSE_g
    psi = 0.19;
@#endif

@#if IMPULSE_sigmaH
	sigma = 2;
@#else
    sigma = 1;
@#endif

% Deep parameters
beta    = 0.995;
delta   = 1;
varphi  = 5;
eps     = 9;
alpha   = 0.25;
theta 	= 0.75;
set_param_value('eta',eta)
set_param_value('psi',psi)
rhou    = 0.9;
rhov    = 0.92;
rhoz    = 0.9;
sigu    = 0.1;	%Percent
sigv    = 11;   %Percent
sigz    = 6;    %Percent

% Growth rate of money
mu = 0;

% Some parameter changes for sensitivity analysis
% beta  = 0.996;
% rhoz  = 0.0;
% mu    = 0.45; %Percent

% Combined parameters
rho  	= -log(beta)*100; %Percent
lambda	= (1-theta)*(1-beta*theta)*(1-alpha)/(theta*(1-alpha+alpha*eps));
kappa   = lambda*(sigma+(alpha+varphi)/(1-alpha));
Gamma   = sigma*(1-alpha)/(alpha+varphi+sigma*(1-alpha));
gamma   = Gamma*(1-Gamma+delta/sigma);
lam_pi  = 1/200*eps/lambda;
lam_yh  = 1/200*kappa/lambda;
lam_g   = 1/200*gamma*kappa/lambda;
lam_i   = 1/200*eta*kappa/lambda;
sigeu   = sigu*sqrt(1-rhou^2);
sigev   = sigv*sqrt(1-rhov^2);
sigez   = sigz*sqrt(1-rhoz^2);

MODEL;
    pi = beta*pi(+1) + kappa*yh + u;
    yh = yh(+1) - 1/sigma*(i - pi(+1) - rn);
    y = c + g;
    yh = y - Gamma*g;
    rn = (1-rhoz)*z - sigma*(1-Gamma)*(g(+1)-g);
    u = rhou*u(-1) + epsu;
    v = rhov*v(-1) + epsv;
    z = rhoz*z(-1) + epsz;    
    r = i - pi(+1);
    pi = p - p(-1);
    dm = m - m(-1);
    g = max(0,-psi*yh);

    @#if MP_i
        m = p + c - eta*i + v;
        @#if ZLB
          % max(pi + yh/eps - i*sigma*eta/eps,-i-rho-mu) = 0;
            max(pi + yh/eps,-i-rho-mu) = 0;
        @#else
          % pi + yh/eps - i*sigma*eta/eps = 0;
            pi + yh/eps = 0;
        @#endif
    @#endif

    @#if MP_p
        m = p + c - eta*i + v;
        @#if ZLB
            max(p,-i-rho-mu) = 0;
        @#else
            p = 0;
        @#endif
    @#endif

    @#if MP_m
        @#if ZLB
            max(-(m - p - c + eta*i - v),-i-rho-mu);
        @#else
            m = p + c - eta*i + v;
        @#endif
        dm = 0;
    @#endif
END;

% Make labels, and display options
@#if WELFARE
    N1='w';
@#endif
@#if IMPULSE
    N1='i';
@#endif

N2='';
@#if WELFARE_u_shock
    N2='u';
    disp('Welfare if u')
@#endif
@#if WELFARE_v_shock
    N2='v';
    disp('Welfare if v')
@#endif
@#if WELFARE_z_shock
    N2='z';
    disp('Welfare if z')
@#endif
@#if WELFARE_demand_shocks
    N2='d';
    disp('Welfare if v and Z')
@#endif

@#if ZLB
    N3='z';
    disp('ZLB')
@#else
    N3='n';
    disp('No ZLB')
@#endif

@#if MP_i
    N4='i';
    disp('IT')
@#endif
@#if MP_m
    N4='m';
    disp('MGT')
@#endif
@#if MP_p
    N4='p';
    disp('PLT')
@#endif

N5='';
@#if IMPULSE_etaL
	N5='etaL';
@#endif
@#if IMPULSE_etaH
    N5='etaH';
@#endif
@#if IMPULSE_sigmaH
    N5='sigmaH';
@#endif

N6='';
@#if IMPULSE_g
    N6='g';
@#endif

disp('Looped parameters:')
disp([' eta: ',num2str(eta)])
disp([' psi: ',num2str(psi)])
disp('Other parameters:')
disp([' sigma: ',num2str(sigma)])
disp(['    mu: ',num2str(mu)])

@#if WELFARE
    SHOCKS;
    @#if WELFARE_u_shock
        var epsu = sigeu^2;
        var epsv = 1e-16;
        var epsz = 1e-16;
    @#endif
    @#if WELFARE_v_shock
        var epsu = 1e-16;
        var epsv = sigev^2;
        var epsz = 1e-16;
    @#endif
    @#if WELFARE_z_shock
        var epsu = 1e-16;
        var epsv = 1e-16;
        var epsz = sigez^2;
    @#endif
    @#if WELFARE_demand_shocks
        var epsu = 1e-16;
        var epsv = sigev^2;
        var epsz = sigez^2;
    @#endif
    END;
    
    % Make extended path, check convergence
  % extended_path(solver_periods=200,periods=10000,lmmcp);
    extended_path(solver_periods=200,periods=10000);
    if  length(oo_.endo_simul)<length(oo_.exo_simul)
        disp('Failed to converge, increased solver periods to 500.')
        extended_path(solver_periods=500,periods=10000);
        if  length(oo_.endo_simul)<length(oo_.exo_simul)
            disp('Failed to converge!')
            return
        end
    end
    endo = oo_.endo_simul;

    % Statistics
    endo_min  = min(endo');
    endo_mean = mean(endo');
    endo_max  = max(endo');
    endo_std  = std(endo');   
    endo_stats = [endo_min; endo_mean; endo_max; endo_std]'
      
    % Welfare loss in percent
    var_pi = var(endo(1,:));
    var_yh = var(endo(2,:));
    var_g  = var(endo(3,:));
    var_i  = var(endo(4,:));
    l_pi = lam_pi*var_pi;
    l_yh = lam_yh*var_yh;
    l_g  = lam_g*var_g;
    l_i  = lam_i*var_i;
    l_tot = l_pi + l_yh + l_g;
    l_toti = l_tot + l_i;
    loss = [l_tot l_toti l_pi l_yh l_g l_i];

    % ZLB episodes
    ipath = endo(4,:);
    imin = min(ipath+rho+mu);
    k = ipath<=-rho-mu;
    p0 = diff(k);
    p1 = find(p0==-1);
    p2 = find(p0==1);
    if     length(p1)>length(p2), p1=p1(2:end);
    elseif length(p1)<length(p2), p2=p2(2:end);
    end
    if p1>p2, p0 = p1 - p2;
    else,     p0 = p2 - p1;
    end
    zpr = mean(k)*100;	% Pr(ZLB) in percent
    zdur = mean(p0);    % Mean duration in quarters
    zmax = max(p0);     % Max
    if isempty(p0)
        zdur = 0;
        zmax = 0;
    end
    bind = [imin zpr zdur zmax];

    % Gather results    
    @#if WELFARE_LOOP_eta
        R(je,:) = [eta loss bind]
        save([N1 N2 N3 N4 '_eta'],'R')
    @#endif
    @#if WELFARE_LOOP_psi
        R(jp,:) = [psi loss bind]
        save([N1 N2 N3 N4 '_psi'],'R')
    @#endif
    disp(' ')
@#endif

@#if IMPULSE
    np = 28;	% Number of periods to show and save
    nsdu = 2;	% Number of standard deviations for shocks
    nsdv = 3;
    nsdz = 2;
    disp('Use for calibration of impulses:')
    disp([' epsv: ',num2str(sigv*nsdv)])
    disp([' epsz: ',num2str(sigz*nsdz)])
    disp([' epsu: ',num2str(sigu*nsdu)])

    disp(' ')
    disp('Response to -v:')
    SHOCKS;
    var epsv;
        periods 1:1;
        values -33; % set to "-epsv"
    END;
    simul(periods=200,lmmcp);
    endo_vn = oo_.endo_simul;
    endo_vn(:,1:np+1)'

    disp(' ')
    disp('Response to -z:')
    SHOCKS;
    var epsv;
        periods 1:1;
        values 0;
    var epsz;
        periods 1:1;
        values -12; % set to "-epsz"
      % values -24;
    END;
    simul(periods=200,lmmcp);
    endo_zn = oo_.endo_simul;
    endo_zn(:,1:np+1)'

    disp(' ')
    disp('Response to -u:')
    SHOCKS;
    var epsv;
        periods 1:1;
        values 0;
    var epsz;
        periods 1:1;
        values 0;
    var epsu;
        periods 1:1;
        values -0.2; % set to "-epsu"
    END;
    simul(periods=200,lmmcp);
    endo_un = oo_.endo_simul;
    endo_un(:,1:np+1)'

    % Rescale shocks for plotting
    endo_un(12,:) = endo_un(12,:)/sigu;
    endo_vn(13,:) = endo_vn(13,:)/sigv;
    endo_zn(14,:) = endo_zn(14,:)/sigz;

    % Gather results
    endo_un = [nan(size(oo_.steady_state)) endo_un(:,2:np+1)];
    endo_vn = [nan(size(oo_.steady_state)) endo_vn(:,2:np+1)];
    endo_zn = [nan(size(oo_.steady_state)) endo_zn(:,2:np+1)];
    save([N1 N2 N3 N4 N5 N6],'endo_un','endo_vn','endo_zn')
@#endif

% End of loops
end
end